//@line 36 "/buildbot/linux_repack/build/releases/l10n-mozilla-1.9.2/sq/mail/all-l10n.js"

//@line 38 "/buildbot/linux_repack/build/releases/l10n-mozilla-1.9.2/sq/mail/all-l10n.js"

pref("general.useragent.locale", "sq");
